summaryrefslogtreecommitdiff
path: root/plugins/ExternalAPI/m_toptoolbar.h
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/ExternalAPI/m_toptoolbar.h')
-rw-r--r--plugins/ExternalAPI/m_toptoolbar.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/plugins/ExternalAPI/m_toptoolbar.h b/plugins/ExternalAPI/m_toptoolbar.h
index 40735aa17c..6b72a179da 100644
--- a/plugins/ExternalAPI/m_toptoolbar.h
+++ b/plugins/ExternalAPI/m_toptoolbar.h
@@ -163,8 +163,8 @@ struct TTBCtrl
int nButtonWidth;
int nButtonHeight;
int nButtonSpace;
- int nLastHeight; // fix against recursion in WM_SIZE
- int nLineCount;
+ int nLastHeight; // fix against recursion in WM_SIZE
+ BOOL bOrderChanged; // set by buttons' arrange procedure if the buttons' order was changed
BOOL bFlatButtons, bAutoSize, bSingleLine;
SortedList* pButtonList;